### Katharà

Katharà is a lightweight network emulation system based on Docker containers.
It can be really helpful in showing interactive demos/lessons, testing production networks in a sandbox environment, or developing new network protocols.

This setup will install Katharà __VERSION__ on your computer. You will be guided through the steps necessary to install this software.

Click "Continue" to continue the setup.